<?php
/**
* @package      System plugin which replaces the default J4 favicon
* @version      1.0.0
* @author       http://www.brainforge.co.uk
* @copyright    Copyright (C) 2015-2022 Jonathan Brain. All rights reserved.
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

// No direct access
defined('_JEXEC') or die;

use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Uri\Uri;

class plgSystemBffavicon extends CMSPlugin {
	protected $app;

	public function onBeforeCompileHead() {
		$application = intval($this->params->get('application', 1));

		if (!(
			($application & 1 && $this->app->isClient('site')) ||
			($application & 2 && $this->app->isClient('administrator'))
		))
		{
			return;
		}

		$location = $this->params->get('location');
		if (empty($location)) return;
		$location = trim($location, '/');

		$favicons = $this->params->get('favicons');
		if (empty($favicons)) return;

		$document = $this->app->getDocument();
		foreach ($document->_links as $k => $array)
		{
			switch ($array['relation'])
			{
				case 'icon':
				case 'alternate icon':
				case 'mask-icon':
					unset($document->_links[$k]);
					break;
			}
		}

		foreach (explode("\n", $favicons) as $favicon)
		{
			$properties            = [];
			$properties['attribs'] = [];
			foreach (explode(',', trim($favicon)) as $property)
			{
				$property = explode('=', $property, 2);
				$name     = trim($property[0]);
				$value    = trim($property[1], "/ \t\n\r\0\x0B");
				switch ($name)
				{
					case 'href':
						if (!is_file(JPATH_ROOT . '/' . $location . '/' . $value))
						{
							continue 3;
						}
					case 'rel':
						$properties[$name] = $value;
						break;
					default:
						$properties['attribs'][$name] = $value;
						break;
				}
			}
			$document->addHeadLink(Uri::root(true) . '/' . $location . '/' . $properties['href'],
				$properties['rel'], 'rel', $properties['attribs']);
		}
	}
}
?>